==> 6.6.3-0-202403191846qtgrpc-everywhere-src-6.6.3.tar.xz: 6.6.3/Src/qtgrpc/tests/auto/protobufgen/data/expected_result/qmlgen/enummessages_protobuftyperegistrations.cpp <==
#include <QtProtobuf/qprotobufserializer.h>
#include "enummessages.qpb.h"

namespace qtprotobufnamespace::tests {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarSimpleEnumMessage(qRegisterProtobufType<SimpleEnumMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarRepeatedEnumMessage(qRegisterProtobufType<RepeatedEnumMessage>);
namespace MixedEnumUsageMessage_QtProtobufNested {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolder(qRegisterProtobufType<NestedEnumHolder>);
namespace NestedEnumHolderLevel1_QtProtobufNested {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolderLevel2(qRegisterProtobufType<NestedEnumHolderLevel2>);
} // namespace NestedEnumHolderLevel1_QtProtobufNested
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolderLevel1(qRegisterProtobufType<NestedEnumHolderLevel1>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumMessage(qRegisterProtobufType<NestedEnumMessage>);
} // namespace MixedEnumUsageMessage_QtProtobufNested
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarMixedEnumUsageMessage(qRegisterProtobufType<MixedEnumUsageMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarSimpleFileEnumMessage(qRegisterProtobufType<SimpleFileEnumMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarStepChildEnumMessage(qRegisterProtobufType<StepChildEnumMessage>);
static bool RegisterEnummessagesProtobufTypes = [](){ qRegisterProtobufTypes(); return true; }();
} // namespace qtprotobufnamespace::tests

==> 6.7.0-0-202310031040qtgrpc-everywhere-src-6.7.0.tar.xz: 6.7.0/Src/qtgrpc/tests/auto/protobufgen/data/expected_result/qmlgen/enummessages_protobuftyperegistrations.cpp <==
#include <QtProtobuf/qprotobufserializer.h>
#include "enummessages.qpb.h"

namespace qtprotobufnamespace::tests {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarSimpleEnumMessage(qRegisterProtobufType<SimpleEnumMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarRepeatedEnumMessage(qRegisterProtobufType<RepeatedEnumMessage>);
namespace MixedEnumUsageMessage_QtProtobufNested {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolder(qRegisterProtobufType<NestedEnumHolder>);
namespace NestedEnumHolderLevel1_QtProtobufNested {
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolderLevel2(qRegisterProtobufType<NestedEnumHolderLevel2>);
} // namespace NestedEnumHolderLevel1_QtProtobufNested
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumHolderLevel1(qRegisterProtobufType<NestedEnumHolderLevel1>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarNestedEnumMessage(qRegisterProtobufType<NestedEnumMessage>);
} // namespace MixedEnumUsageMessage_QtProtobufNested
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarMixedEnumUsageMessage(qRegisterProtobufType<MixedEnumUsageMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarSimpleFileEnumMessage(qRegisterProtobufType<SimpleFileEnumMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarStepChildEnumMessage(qRegisterProtobufType<StepChildEnumMessage>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarA(qRegisterProtobufType<A>);
static QtProtobuf::ProtoTypeRegistrar ProtoTypeRegistrarB(qRegisterProtobufType<B>);
} // namespace qtprotobufnamespace::tests
